@@ -2,25 +2,34 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Minnispunktar",
-    "The last viewed note cannot be accessed. " : "Ekki hægt að lesa síðast skoðaða minnispunktinn.",
-    "The notes folder is not accessible: %s" : "Mappa undir minnispunkta er ekki aðgengileg: %s",
     "New note" : "Nýr minnispunktur",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Það eru óvistaðir minnispunktar. Ef farið er af síðunni munu allar breytingar tapast!",
     "Please wait while new settings are applied…" : "Bíddu á meðan nýju stillingarnar eru virkjaðar…",
     "_%n word_::_%n words_" : ["%n orð","%n orð"],
+    "Updating the note's category has failed. Is the target directory writable?" : "Uppfærsla á flokki minnispunkts mistókst. Er móttökumappan skrifanleg?",
+    "The last viewed note cannot be accessed. " : "Ekki hægt að lesa síðast skoðaða minnispunktinn.",
+    "The notes folder is not accessible: %s" : "Mappa undir minnispunkta er ekki aðgengileg: %s",
     "File error" : "Villa í skrá",
     "Encryption Error" : "Villa í dulritun",
     "Error" : "Villa",
-    "Delete note" : "Eyða minnispunkti",
-    "Favorite" : "Eftirlæti",
+    "Distraction-free notes and writing" : "Augljós ritun og skoðun minnispunkta",
+    "Uncategorized" : "Óflokkað",
+    "Categories" : "Flokkar",
+    "All notes" : "Allir minnispunktar",
+    "Search result for \"{{search}}\" in {{SelectedCategory}}" : "Leitarniðurstöður fyrir \"{{search}}\" í {{SelectedCategory}}",
+    "Search result for \"{{search}}\"" : "Leitarniðurstöður fyrir {{search}}\"",
+    "No search result for {{search}} in {{SelectedCategory}}" : "Engar leitarniðurstöður fyrir \"{{search}}\" í {{SelectedCategory}}",
     "No search result for {{search}}" : "Engar leitarniðurstöður fyrir {{search}}",
     "No notes found" : "Engir minnispunktar fundust",
+    "Delete note" : "Eyða minnispunkti",
+    "Favorite" : "Eftirlæti",
     "Settings" : "Stillingar",
     "Folder to store your notes" : "Mappa til að geyma minnispunktana þína",
     "path to notes" : "slóð að minnispunktum",
     "File extension for new notes" : "Skráarending fyrir nýja minnispunkta",
+    "Category" : "Flokkur",
+    "Edit category" : "Breyta flokki",
     "The note has unsaved changes." : "Minnispunkturinn er með óvistaðar breytingar.",
-    "*" : "*",
     "Click here to try again" : "Smelltu hér til að reyna aftur",
     "Saving failed!" : "Vistun mistókst!",
     "Note saved" : "Vistaði minnispunkt"
